@@ -2,6 +2,7 @@ mod use_async;
 mod use_before_unload;
 mod use_click_away;
 mod use_counter;
+mod use_drop;
 mod use_effect_once;
 mod use_effect_update;
 mod use_event;
@@ -42,6 +43,7 @@ pub use use_async::*;
 pub use use_before_unload::*;
 pub use use_click_away::*;
 pub use use_counter::*;
+pub use use_drop::*;
 pub use use_effect_once::*;
 pub use use_effect_update::*;
 pub use use_event::*;
